@@ -1,11 +1,11 @@
 # Copyright (c) 2012 gocept gmbh & co. kg
 # See also LICENSE.txt
 
-"""Platform-specific services"""
+"""Platform-specific services."""
 
 import os
 
-platform = __import__('nagiosplugin.platform.%s' % os.name,
+platform = __import__('nagiosplugin.platform.{}'.format(os.name),
                       fromlist=['with_timeout', 'flock_exclusive'])
 
 with_timeout = platform.with_timeout
