@@ -3,16 +3,15 @@
 
 """POSIX implementation of platform-specific services"""
 
-from __future__ import print_function, unicode_literals
-from nagiosplugin.errors import TimeoutError
+import nagiosplugin
 import fcntl
 import signal
 
 
-def with_timeout(t, func, args=(), kwargs={}):
+def with_timeout(t, func, *args, **kwargs):
     """Call `func` but terminate after `t` seconds."""
     def timeout_handler(signum, frame):
-        raise TimeoutError('timeout exceeded')
+        raise nagiosplugin.Timeout('{}s'.format(t))
 
     signal.signal(signal.SIGALRM, timeout_handler)
     signal.alarm(t)
